# This file is used for defining paths common to both the tracker and
# the various filter scripts (and a few others).
#
# Lines such as this one, which start with '#', are comments.
# Strings within this file must be quoted if they contain spaces. Strings
# in tcl can be quoted either with the usual double-quotes or with '{'
# and '}'.  Note that these are handled VERY differently....
#
# If you have a quoted string such as "This is a very $mood day" ... the
# contents of the variable, $mood, will be substituted when the string is
# read.  Likewise, if you have a command called "get_mood", another
# version of the previous string might be "This is a very [get_mood] day."
#
# The '$' and '[' characters are special.  If you need them in a string,
# escape them with a backslash, e.g., "This software costs \$0.00."
# Fortunately, you're not likely to need these for anything found in
# this file!
#
# Strings quoted with '{' and '}' are handled very differently.
# Basically, variables, etc., within the string are not evaluated
# immediately when the string is read.  Use this type of quoting only
# if you're familiar with Tcl.

# The location for tclsh8x(.exe) and wish8x(.exe)
set tclshbin "/usr/local/bin/tclsh8.5"
set wishbin "/usr/local/bin/wish8.5"

# Change the directory below to refer to the location where these
# scripts are being installed.  If you are always running this from
# the current directory (i.e., you're running it from the directory
# where the scripts are installed), you're done.

# My systems
#    set install_dir d:/jdg/src/ht     ;# work, home w/ XP machine
#    set install_dir /home/jim/src/ht  ;# home w/ FreeBSD and Linux machines
#
# Typical location (multi-user use) for Unix systems
#    set install_dir /usr/local/lib/jstrack
# Typical location (multi-user use) for WinXX systems
#    set install_dir c:/jstrack
# install_dir value determined by autoconfig.tcl:
set install_dir "/usr/local/lib/jstrack"
# Directory for storm data (must be an absolute path, e.g.,
# /usr/local/lib/jstrack or $install_dir/tracker/storms).
#
# NOTE:  For filt.tcl, you can override this variable on the command
# line with
#    filt.tcl -stormdir /foo/bar [filename]
# where filename is optional.

# FYI/WARNING:  autoconfig is assuming the default location for storm data!
set storms $install_dir/tracker/storms

# ####################################################################
# Assuming you haven't changed the directory layout of the JStrack   #
# distribution, you're done.  If you've changed the layout, you need #
# to modify the following to match what you've done....  Note that,  #
# depending on what you've changed, you may also need to modify any  #
# files that source this file!                                       #
# ####################################################################
set trackdir $install_dir/tracker
set libdir $trackdir/lib
set imgdir $trackdir/lib/images
set rfcdir $install_dir/filt
set filt_path $install_dir/filt/filt.tcl
set ftpdir $install_dir/ftpfilt
set ftpfilt $install_dir/ftpfilt/ftp.tcl
set httpfilt_path  $install_dir/httpfilt

